@@ -2,7 +2,8 @@ import pytest
 
 from mindee.client import Client
 from mindee.product.invoice.invoice_v4 import InvoiceV4
-from tests.product import PRODUCT_DATA_DIR, get_id, get_version
+from tests.product import get_id, get_version
+from tests.utils import PRODUCT_DATA_DIR
 
 
 @pytest.mark.regression
